# encoding:utf-8
# 发布文件
# 从Python发布工具导入"setup"函数
from distutils.core import setup


setup(
    name='fullzear',
    version='1.0.0',

    author='yangpeng',
    author_email='877768999@qq.com',
    url='https://github.com/hyypan',
    description='这是我的第一次发布安装文件'
)